@@ -22,7 +22,9 @@ boost_dpp <- function(formula, data, weights = NULL, na.action = na.omit, ...) {
     if (length(y) != 1)
         stop("cannot deal with multivariate response variables")
     y <- y[[1]]
-    x <- env@get("designMatrix")
+    x <- NA
+    if (has(env, "designMatrix"))
+        x <- env@get("designMatrix")
 
     if (is.factor(y)) {
         if (nlevels(y) != 2)
@@ -389,11 +391,6 @@ smoothbase <- function(x, ux, y, w, df) {
     fit.object <- list(knot = knot, nk = nk, min = ux[1], range = r.ux,
 		       coef = fit$coef)
     class(fit.object) <- "smooth.spline.fit"
-    if (length(ux) == length(x)) {
-        fit.object$yfit <- fit$ty[rank(x)]
-    } else {
-        fit.object$yfit <- predict(fit.object, x = x)$y
-    }
     fit.object
 }
 
@@ -406,20 +403,23 @@ predict.lmfit <- function(object, newdata) {
 }
 
 ### trace boosting iterations
-do_trace <- function(m, risk, step = options("width")$width / 2, 
+do_trace <- function(m, risk, step = options("width")$width / 2,
                      width = 1000) {
 
-    if ((m - 1) %/% step == (m - 1) / step) {
-        mchr <- formatC(m, format = "d", width = nchar(width) + 1, 
-                        big.mark = "'")
-        cat(paste("[", mchr, "] ",sep = ""))
-    } else {
-        if ((m %/% step != m / step) && m != width) {
-            cat("*")
+    if (m != width) {
+        if ((m - 1) %/% step == (m - 1) / step) {
+            mchr <- formatC(m, format = "d", width = nchar(width) + 1,
+                            big.mark = "'")
+            cat(paste("[", mchr, "] ",sep = ""))
         } else {
-            if (m == width) cat(rep(" ", step - width %% step - 1))
-            cat("* -- risk:", risk[m], "\n")
-        }
+            if ((m %/% step != m / step)) {
+                cat(".")
+            } else {
+                cat(" -- risk:", risk[m], "\n")
+            }
+        }    
+    } else {
+        cat("\nFinal risk:", risk[m], "\n")
     }
 }
 
